# pyilluminate

Python interface for controlling the [Illuminate](https://github.com/zfphil/illuminate) boards.

All units to this interface are in SI units.

Copyright (C) 2018-2022, Ramona Optics, Inc.
